<?php
/*
Plugin Name: SerplifyWP
Plugin URI: http://serplifyapp.com/
Description: Serplify plugin to extend Wordpress functionality
Author: Serplify
Version: 1.0
Author URI: http://serplifyapp.com/
*/

include_once('/home/ezapndgg/public_html/promoapparels.com/wp-includes/class-IXR.php');
include_once('/home/ezapndgg/public_html/promoapparels.com/wp-includes/class-wp-xmlrpc-server.php');
//include_once(ABSPATH . WPINC . '/class-IXR.php');
//include_once(ABSPATH . WPINC . '/class-wp-xmlrpc-server.php');

class LSEOP_XmlRpc extends wp_xmlrpc_server {

    private $version = 1.0;

    public function __construct() {
        parent::__construct();

        $methods = array(
            'lseop.check' => 'this:lseop_check',
            'lseop.newUsers' => 'this:lseop_newUsers',
            'lseop.flushPermalinks' => 'this:lseop_flushPermalinks'
        );

        $this->methods = array_merge($this->methods, $methods);

        $this->blog_options['permalink_structure'] = array(
            'desc'          => __( 'Permalink Structure' ),
            'readonly'      => false,
            'option'        => 'permalink_structure'
        );
    }

    public static function lseop_getName() {
        return __CLASS__;
    }

    public function lseop_check($args) {
        return $this->version;
    }

    public function lseop_newUsers($args) {
        global $wp_xmlrpc_server;
        $wp_xmlrpc_server->escape($args);

        $blog_id  = $args[0];
        $username = $args[1];
        $password = $args[2];

        if ( ! $user = $wp_xmlrpc_server->login( $username, $password ) )
            return $wp_xmlrpc_server->error;

        if ( ! user_can( $user, 'create_users' ) )
            return 'User does not have permission to create users';

        if(is_array($args[3])){
            //if arg with index 3 is an array then we are adding multiple users
            $result = array();

            foreach($args[3] as $newUser){
                $new_username = $newUser['new_username'];
                $new_password = $newUser['new_password'];
                $new_email = $newUser['new_email'];
                $new_role = strtolower($newUser['new_role']);

                try{
                    $new_user_id = $this->lseop_newUser($new_username, $new_password, $new_email, $new_role);
                }catch(\Exception $e){
                    //shouldn't be any errors thrown but catch them if there is and return result as exception message
                    $singleResult = array(
                        'user_created' => false,
                        'error' => $e->getMessage()
                    );
                }

                if ( is_int($new_user_id)){
                    //user created
                    $singleResult = array(
                        'user_created' => true,
                        'id' => $new_user_id,
                        'username' => $new_username,
                        'password' => $new_password,
                        'email' => $new_email,
                        'role' => $new_role
                    );
                }else{
                    //was an error
                    $singleResult = array(
                        'user_created' => false,
                        'error' => $new_user_id,
                        'username' => $new_username,
                        'password' => $new_password,
                        'email' => $new_email,
                        'role' => $new_role,
                    );
                }

                array_push($result, $singleResult);
            }
        }else{
            //adding a single user
            $new_username = $args[3];
            $new_password = $args[4];
            $new_email = $args[5];
            $new_role = strtolower($args[6]);

            $new_user_id = $this->lseop_newUser($new_username, $new_password, $new_email, $new_role);

            if ( is_int($new_user_id)){
                //user created
                $result = array(
                    'user_created' => true,
                    'id' => $new_user_id,
                    'username' => $new_username,
                    'password' => $new_password,
                    'email' => $new_email,
                    'role' => $new_role
                );
            }else{
                //was an error
                $result = array(
                    'user_created' => false,
                    'error' => $new_user_id,
                    'username' => $new_username,
                    'password' => $new_password,
                    'email' => $new_email,
                    'role' => $new_role
                );
            }
        }

        return $result;
    }

    private function lseop_newUser($username, $password, $email, $role){
        $validRoles = array('administrator', 'editor', 'author', 'contributor', 'subscriber');

        if( empty( $username ) )
            return 'New username is empty';

        if( empty( $password ) )
            $password = wp_generate_password( $length=12, $include_standard_special_chars=false );

        if( empty( $email ) )
            return 'New email is empty';

        if( !empty( $email ) ){
            if ( !filter_var( $email, FILTER_VALIDATE_EMAIL )) {
                return "Invalid new email address";
            }
        }

        if( !empty($role) && !in_array( $role, $validRoles ) )
            return 'Invalid new role';

        $user_id = wp_create_user( $username, $password, $email );

        if (!is_int($user_id)){
            //user wasn't created so return error message
            return $user_id->get_error_message();
        }else if(!empty($role) ){
            //need to set new user role

            $user = new WP_User($user_id);
            $user->set_role($role);
        }

        return $user_id;
    }

    public function lseop_flushPermalinks($args) {
        global $wp_rewrite;

        $wp_rewrite->flush_rules();

        return 'flushed';
    }

    public static function lseop_notify(){
        $response = wp_remote_post( 'http://serplifyapp.com/sites/plugin_notify', array(
                'method' => 'POST',
                'body' => array(
                    'url' => get_site_url(),
                    'plugin_version' => '1.0'
                ),
            )
        );
    }
}

class LSEOP_SEO{
    public static function lseop_title() {
        $post_id = get_the_ID();

        if ( !empty( $post_id ) ) {
            $lseop_title = get_post_meta( $post_id, 'lseop_title', true );

            if ( !empty( $lseop_title ) ){
                return esc_html( $lseop_title );
            }
        }
    }

    public static function lseop_meta_description() {
        $post_id = get_the_ID();

        if ( !empty( $post_id ) ) {
            $lseop_description = get_post_meta( $post_id, 'lseop_description', true );

            if ( !empty( $lseop_description ) ){
                echo '<meta name="description" content="' . esc_html( $lseop_description ) . '">';
            }
        }
    }

    public static function lseop_meta_keywords() {
        $post_id = get_the_ID();

        if ( !empty( $post_id ) ) {
            $lseop_keywords = get_post_meta( $post_id, 'lseop_keywords', true );

            if ( !empty( $lseop_keywords ) ){
                $keywords = array_map(array(__CLASS__, 'lseop_meta_keywords_process'), $lseop_keywords);
                echo '<meta name="keywords" content="' . implode(',', $keywords) . '">';
            }
        }
    }

    public static function lseop_meta_keywords_process($keyword){
        return trim(esc_html($keyword));
    }
}

add_filter('wp_xmlrpc_server_class', array('LSEOP_XmlRpc', 'lseop_getName'));
add_filter( 'pre_get_document_title', array('LSEOP_SEO', 'lseop_title'));
add_filter( 'wp_head', array('LSEOP_SEO', 'lseop_meta_description'));
add_filter( 'wp_head', array('LSEOP_SEO', 'lseop_meta_keywords'));
register_activation_hook( __FILE__, array( 'LSEOP_XmlRpc', 'lseop_notify' ) );

?>